@@ -21,7 +21,10 @@ from djf_surveys.forms import BaseSurveyForm
 class AdminCrateSurveyView(ContextTitleMixin, CreateView):
     model = Survey
     template_name = 'djf_surveys/admins/form.html'
-    fields = ['name', 'description', 'editable', 'deletable', 'duplicate_entry']
+    fields = [
+        'name', 'description', 'editable', 'deletable', 
+        'duplicate_entry', 'private_response', 'can_anonymous_user'
+    ]
     title_page = "Add New Survey"
 
     def post(self, request, *args, **kwargs):
@@ -39,7 +42,10 @@ class AdminCrateSurveyView(ContextTitleMixin, CreateView):
 class AdminEditSurveyView(ContextTitleMixin, UpdateView):
     model = Survey
     template_name = 'djf_surveys/admins/form.html'
-    fields = ['name', 'description', 'editable', 'deletable', 'duplicate_entry']
+    fields = [
+        'name', 'description', 'editable', 'deletable', 
+        'duplicate_entry', 'private_response', 'can_anonymous_user'
+    ]
     title_page = "Edit Survey"
 
     def get_success_url(self):
@@ -177,7 +183,7 @@ class DownloadResponseSurveyView(DetailView):
                 header.append('user')
                 header.append('update_at')
 
-            rows.append(user_answer.user.username)
+            rows.append(user_answer.user.username if user_answer.user else 'no auth')
             rows.append(user_answer.updated_at.strftime("%Y-%m-%d %H:%M:%S"))
             for answer in user_answer.answer_set.all():
                 if index == 0:
