@@ -27,7 +27,6 @@ class SurveyListView(ContextTitleMixin, ListView):
         return object_list
 
 
-@method_decorator(login_required, name='dispatch')
 class SurveyFormView(FormMixin, DetailView):
     template_name = 'djf_surveys/form.html'
     success_url = "/"
@@ -44,7 +43,6 @@ class SurveyFormView(FormMixin, DetailView):
             return self.form_invalid(form)
 
 
-@method_decorator(login_required, name='dispatch')
 class CreateSurveyFormView(ContextTitleMixin, SurveyFormView):
     model = Survey
     form_class = CreateSurveyForm
@@ -52,12 +50,17 @@ class CreateSurveyFormView(ContextTitleMixin, SurveyFormView):
     title_page = "Add Survey"
 
     def dispatch(self, request, *args, **kwargs):
-        # handle if user have answer survey
         survey = self.get_object()
-        if not survey.duplicate_entry and \
+        # handle if survey can_anonymous_user
+        if not request.user.is_authenticated and not survey.can_anonymous_user:
+            messages.warning(request, 'Sorry, you must be logged in to fill out the survey')
+            return redirect("/")
+
+        # handle if user have answer survey
+        if request.user.is_authenticated and not survey.duplicate_entry and \
                 UserAnswer.objects.filter(survey=survey, user=request.user).exists():
             messages.warning(request, 'You have submitted out this survey')
-            return redirect("djf_surveys:detail", slug=survey.slug)
+            return redirect("/")
         return super().dispatch(request, *args, **kwargs)
 
     def get_form(self, form_class=None):
@@ -129,6 +132,13 @@ class DetailSurveyView(ContextTitleMixin, DetailView):
     title_page = "Result Survey"
     paginate_by = 6
 
+    def dispatch(self, request, *args, **kwargs):
+        survey = self.get_object()
+        if not self.request.user.is_superuser and survey.private_response:
+            messages.warning(request, "You can't access this page")
+            return redirect("/")
+        return super().dispatch(request, *args, **kwargs)
+
     def get_context_data(self, **kwargs):
         user_answers = UserAnswer.objects.filter(survey=self.get_object()) \
             .select_related('user').prefetch_related('answer_set__question')
@@ -138,3 +148,30 @@ class DetailSurveyView(ContextTitleMixin, DetailView):
         context = super().get_context_data(**kwargs)
         context['page_obj'] = page_obj
         return context
+
+
+@method_decorator(login_required, name='dispatch')
+class DetailResultSurveyView(ContextTitleMixin, DetailView):
+    title_page = "Detail Result"
+    template_name = "djf_surveys/detail_result.html"
+    model = UserAnswer
+
+    def get_context_data(self, **kwargs):
+        context = super().get_context_data(**kwargs)
+        context['object'] = self.get_object()
+        context['on_detail'] = True
+        return context
+
+    def dispatch(self, request, *args, **kwargs):
+        # handle if user not same
+        user_answer = self.get_object()
+        if user_answer.user != request.user:
+            messages.warning(request, "You can't this. You don't have permission")
+            return redirect("/")
+        return super().dispatch(request, *args, **kwargs)
+
+    def get_title_page(self):
+        return self.get_object().survey.name
+
+    def get_sub_title_page(self):
+        return self.get_object().survey.description
